@@ -2,7 +2,7 @@ package App::ModuleBuildTiny::Dist;
 
 use 5.014;
 use warnings;
-our $VERSION = '0.043';
+our $VERSION = '0.044';
 
 use CPAN::Meta;
 use Config;
@@ -240,6 +240,7 @@ sub new {
 		my $prereqs = load_prereqs($provides, %opts);
 		$prereqs->{configure}{requires}{'Module::Build::Tiny'} //= mbt_version();
 		$prereqs->{develop}{requires}{'App::ModuleBuildTiny'} //= $VERSION;
+		my %resources = $class->generate_resources(%opts);
 
 		my $metahash = {
 			name           => $distname,
@@ -255,6 +256,7 @@ sub new {
 				version    => '2',
 				url        => 'http://search.cpan.org/perldoc?CPAN::Meta::Spec'
 			},
+			(resources      => \%resources) x!! %resources,
 			x_spdx_expression => $license->spdx_expression,
 		};
 		if (%{$mergedata}) {
@@ -321,6 +323,52 @@ sub new {
 	}, $class
 }
 
+
+sub generate_resources {
+	my ($class, %opts) = @_;
+	my %result;
+
+	if ($opts{add_repository}) {
+		require Git::Wrapper;
+		my $git = Git::Wrapper->new('.');
+		my ($origin) = $git->remote('get-url' => 'origin');
+		if ($origin =~ m{https://github.com/([\w.-]+)/([\w.-]+).git}) {
+			$result{repository} = {
+				type => 'git',
+				web  => "https://github.com/$1/$2/",
+				url  => $origin,
+			};
+		} elsif ($origin =~ m{git\@github.com:([\w.-]+)/([\w.-]+).git}) {
+			$result{repository} = {
+				type => 'git',
+				web  => "https://github.com/$1/$2/",
+				url  => "https://github.com/$1/$2.git",
+			};
+		} elsif ($origin =~ m{^https?://}) {
+			$result{repository} = {
+				type => 'git',
+				url  => $origin,
+			};
+		}
+	}
+
+	if ($opts{add_bugtracker}) {
+		require Git::Wrapper;
+		my $git = Git::Wrapper->new('.');
+		my ($origin) = $git->remote('get-url' => 'origin');
+		if ($origin =~ m{https://github.com/([\w.-]+)/([\w.-]+).git}) {
+			$result{bugtracker} = {
+				web  => "https://github.com/$1/$2/issues",
+			};
+		} elsif ($origin =~ m{git\@github.com:([\w.-]+)/([\w.-]+).git}) {
+			$result{bugtracker} = {
+				web  => "https://github.com/$1/$2/issues",
+			};
+		}
+	}
+	return %result;
+}
+
 sub write_dir {
 	my ($self, $dir, $verbose) = @_;
 	mkpath($dir, $verbose, oct '755');
@@ -344,9 +392,8 @@ sub write_tarball {
 	for my $filename ($self->files) {
 		$arch->add_data($filename, $self->get_file($filename), { mode => oct '0644'} );
 	}
-	my $file = $name . ".tar.gz";
-	$arch->write($file, &Archive::Tar::COMPRESS_GZIP, $name);
-	return $file;
+	$arch->write($name, &Archive::Tar::COMPRESS_GZIP, $name);
+	return $name;
 }
 
 sub files {
@@ -403,4 +450,10 @@ sub fullname {
 	my $trial = $self->release_status eq 'testing' && $self->version !~ /_/;
 	return $self->meta->name . '-' . $self->meta->version . ($trial ? '-TRIAL' : '' );
 }
+
+sub archivename {
+	my $self = shift;
+	return $self->fullname . '.tar.gz';
+}
+
 1;
